@@ -1,13 +1,13 @@
-flat_mod!(float);
+pub mod float;
 
 cfg_if::cfg_if! {
     if #[cfg(feature = "random")] {
-        flat_mod!(random);
+        pub mod random;
     }
 }
 
 cfg_if::cfg_if! {
     if #[cfg(feature = "serialize")] {
-        flat_mod!(serialize);
+        pub mod serialize;
     }
 }
\ No newline at end of file
